================================================================================
moban-ansible
================================================================================

.. image:: https://api.travis-ci.org/moremoban/moban-ansible.svg
   :target: http://travis-ci.org/moremoban/moban-ansible

.. image:: https://codecov.io/github/moremoban/moban-ansible/coverage.png
   :target: https://codecov.io/github/moremoban/moban-ansible
.. image:: https://badge.fury.io/py/moban-ansible.svg
   :target: https://pypi.org/project/moban-ansible

.. image:: https://pepy.tech/badge/moban-ansible/month
   :target: https://pepy.tech/project/moban-ansible/month

.. image:: https://img.shields.io/github/stars/moremoban/moban-ansible.svg?style=social&maxAge=3600&label=Star
    :target: https://github.com/moremoban/moban-ansible/stargazers

.. image:: https://dev.azure.com/moremoban/moban-ansible/_apis/build/status/moremoban.moban-ansible?branchName=master
   :target: https://dev.azure.com/moremoban/moban-ansible/_build/latest?definitionId=2&branchName=master


Installation
================================================================================


You can install moban-ansible via pip:

.. code-block:: bash

    $ pip install moban-ansible


or clone it and install it:

.. code-block:: bash

    $ git clone https://github.com/moremoban/moban-ansible.git
    $ cd moban-ansible
    $ python setup.py install
